@@ -139,7 +139,7 @@ sub classOverview {
             . $self->textClassApi(oClass => $oClass);
 
 
-    my $textOverview = join(
+    my $textOverview = $self->stripTrailingWhitespace(join(
         "\n",
         $textInheritance,
         $textApi,
@@ -147,7 +147,7 @@ sub classOverview {
         $textUses,
         $textNeighbourhood,
 #        $textStructure,
-    );
+    ));
 
     #Highlight the current class
     my $leftBracket = "[[]";
@@ -161,6 +161,8 @@ sub classOverview {
 
 
 
+
+
 =head2 textClassInheritance(oClass)
 
 Return string representing the class hierarchy of $oClass.
@@ -598,6 +600,24 @@ sub escapeValue {
 
 
 
+=head2 stripTrailingWhitespace($string)
+
+Return $string with each line in $string stripped of trailing
+whitespace.
+
+=cut
+sub stripTrailingWhitespace {
+    my ($string) = @_;
+    return join(
+        "\n",
+        map { $_ =~ s/\s+$//; $_ } split("\n", $string), ## no critic
+    );
+}
+
+
+
+
+
 1;
 
 
